.. :changelog:

Changelog
=========

v0.0.3
------
Release Date: 2021-02-04
    * File encryption/decryption added.

v0.0.2
------
Release Date: 2021-02-04
    * Sign and verify added.

v0.0.1
------
Release Date: 2021-02-03
    * Initial package.